# PyMusicOrganizer

CLI tool to keep your music organized.

## Installation

```bash
pipenv install 
```

## Usage

Tu run the tool, you need to specify the path to the folder containing your music files.

```bash
pipenv run main
```

**More Coming Soon**


# TODO:
- Check (PyPoetry)[https://python-poetry.org/] for packaging and publishing
- Switch setup.py to poetry or `package.toml`
